@@ -89,7 +89,7 @@ class DepartmentSchema(Schema):
 
     language = String.using(default="en")
     name = String.using(facet=True)
-    employees = Array.of(String.using(facet=True))
+    employees = Array.of(String).using(facet=True)
 
 
 db = None
@@ -146,12 +146,6 @@ def assert_one(query, name, result, **kw):
     assert getattr(l[0], name) == result
 
 
-def test_no_bogus_db():
-    assert_raises(TypeError, xodb.Database, None)
-    assert_raises(TypeError, xodb.Database, 1)
-    assert_raises(TypeError, xodb.Database, True)
-
-
 def test_empty_query():
     assert len(list(db.query(''))) == 4
 
