@@ -17,7 +17,8 @@ class _TestDatabase(object):
         assert self.db.backend.get_doccount() == 0
 
     def teardown(self):
-        if self.db.db_path:
+        self.db.close()
+        if self.db.db_path and isinstance(self.db.db_path, basestring):
             shutil.rmtree(self.db.db_path)
 
     def test_stored_prefixes(self):
@@ -45,6 +46,10 @@ class TestXapianFile(_TestDatabase):
     db_factory = staticmethod(xodb.temp)
 
 
+class TestXapianInMem(_TestDatabase):
+    db_factory = staticmethod(xodb.inmemory)
+
+
 def test_value_range_processor():
     vp = MultipleValueRangeProcessor(dict(foo=1, bar=2), str.upper)
     assert vp('foo:abc', 'def') == (1, 'ABC', 'DEF')
